@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 """
 Main interface for neptune service client waiters.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.neptune import (
+
+    from mypy_boto3_neptune import NeptuneClient
+    from mypy_boto3_neptune.waiter import (
         DBInstanceAvailableWaiter,
         DBInstanceDeletedWaiter,
     )
@@ -13,19 +17,20 @@ Usage::
 
     db_instance_available_waiter: DBInstanceAvailableWaiter = client.get_waiter("db_instance_available")
     db_instance_deleted_waiter: DBInstanceDeletedWaiter = client.get_waiter("db_instance_deleted")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import List, TYPE_CHECKING
-from botocore.waiter import Waiter as Boto3Waiter
-from mypy_boto3_neptune.type_defs import FilterTypeDef, WaiterConfigTypeDef
+from typing import List
 
+from botocore.waiter import Waiter as Boto3Waiter
+
+from mypy_boto3_neptune.type_defs import FilterTypeDef, WaiterConfigTypeDef
 
 __all__ = ("DBInstanceAvailableWaiter", "DBInstanceDeletedWaiter")
 
 
 class DBInstanceAvailableWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailable)
+    [Waiter.DBInstanceAvailable documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.8/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailable)
     """
 
     def wait(
@@ -37,13 +42,13 @@ class DBInstanceAvailableWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailable.wait)
+        [DBInstanceAvailable.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.8/reference/services/neptune.html#Neptune.Waiter.DBInstanceAvailable.wait)
         """
 
 
 class DBInstanceDeletedWaiter(Boto3Waiter):
     """
-    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeleted)
+    [Waiter.DBInstanceDeleted documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.8/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeleted)
     """
 
     def wait(
@@ -55,5 +60,5 @@ class DBInstanceDeletedWaiter(Boto3Waiter):
         WaiterConfig: WaiterConfigTypeDef = None,
     ) -> None:
         """
-        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.6/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeleted.wait)
+        [DBInstanceDeleted.wait documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.8/reference/services/neptune.html#Neptune.Waiter.DBInstanceDeleted.wait)
         """
